@@ -1,30 +1,20 @@
-#!/usr/bin/perl -w
-
-# $Id$
-# $LastChangedDate$
-# $Rev$
-
+#!/usr/local/bin/perl -w
 use strict;
-use lib qw( ./lib ../lib);
+use lib qw( ./lib ../lib /home/tobeya/work/lib );
 use Nagios::Config;
 use Nagios::Object::Config;
 use Getopt::Std;
 use Benchmark qw(:all);
 use Data::Dumper;
 
-our( $opt_n, $opt_o, $opt_v, $opt_b, $opt_d, $opt_f, $opt_r, $opt_l );
+our( $opt_n, $opt_o, $opt_v, $opt_b, $opt_d, $opt_f );
 getopt( 'n:o:v:' );
-getopt( 'bdfrl' );
+getopt( 'bdf' );
 
 if ( $opt_f ) {
     Nagios::Config->fast_mode(1);
 }
 
-Nagios::Object::Config->strict_mode(undef);
-unless ( $opt_l ) {
-    Nagios::Object::Config->strict_mode(1);
-}
-
 if ( !$opt_n && !$opt_o ) {
     print "Must specify a filename to parse (either -n or -o).\n";
     exit 1;
@@ -39,11 +29,6 @@ if ( $opt_n ) {
 if ( $opt_o ) {
     $obj = Nagios::Object::Config->new( Version => $opt_v );
     $obj->parse( $opt_o );
-
-    if ( $opt_r ) {
-        $obj->resolve_objects;
-        $obj->register_objects;
-    }
 }
 
 if ( $opt_d ) {
